@@ -187,8 +187,8 @@ item_types_without_single_item = \
 inside_space_level_types = \
     [[item_type_environments, item_type_feeds, item_type_machine_policies, item_type_proxies, item_type_tag_sets,
       item_type_worker_pools],
-     [item_type_action_templates, item_type_library_variable_sets, item_type_life_cycles, item_type_project_groups,
-      item_type_workers],  # item_type_teams,
+     [item_type_action_templates, item_type_library_variable_sets, item_type_life_cycles,  # item_type_packages,
+      item_type_project_groups, item_type_workers],  # item_type_teams,
      [item_type_projects],
      [item_type_channels, item_type_runbooks, item_type_tenants],
      [item_type_accounts, item_type_build_information, item_type_certificates, item_type_dashboard_configuration,
@@ -252,7 +252,9 @@ class Config:
         self.no_stdout = False
         self.local_source = False
         self.current_path = None
-        # TODO Octopus demo site bug:
+        self.pem = False
+        # TODO Octopus demo site bug: https://demo.octopus.com/api/runbookprocess
+        # newer site uses https://server/api/runbookprocesses (runbookprocess vs runbookprocesses)
         self.item_type_runbook_processes = item_type_runbook_processes
         self.get_config()
 
@@ -314,13 +316,15 @@ class Common:
         return [item.get(id_key) for item in list_items]
 
     def verify_space(self, space_id_name):
-        list_spaces = self.get_one_type_to_list(item_type=item_type_spaces)
+        all_spaces = self.request_octopus_item(address=item_type_spaces)
+        list_spaces = self.get_list_items_from_all_items(all_items=all_spaces)
         space = find_item(lst=list_spaces, key=id_key, value=space_id_name)
         if space:
             return space.get(id_key)
         space = self.find_single_item_from_list_by_name(list_items=list_spaces, item_name=space_id_name)
         if space:
             return space.get(id_key)
+        self.log_error_print(item=list_spaces, msg=f"{space_id_name} not found")
         return None
 
     # remove the unnecessary modified date/user information from put and post operations
