@@ -1,4 +1,5 @@
 import argparse
+import copy
 import logging
 import os
 
@@ -61,23 +62,24 @@ class OctopusClient:
     def __init__(self):
         self._target_config = Config()
         self._target_common = Common(config=self._target_config)
-        self._source_config = Config()
-        self._source_common = Common(config=self._source_config)
+        self._source_config = None
+        self._source_common = None
 
     @staticmethod
     def _parse_args():
         parser = argparse.ArgumentParser()
         parser.add_argument("-o", double_hyphen + octopus_endpoint_key, help="octopus endpoint")
         parser.add_argument("-s", "--space_id_name", help="octopus space id or name")
-        parser.add_argument("-ss", "--spaces",
-                            help='list of octopus space id or name, like "my_space,Spaces-1,Spaces-2"')
+        parser.add_argument("-m", "--pem", help="octopus endpoint root pem file path")
+        parser.add_argument("-sps", "--spaces",
+                            help='list of octopus space id or name, like "my space,Spaces-1,Spaces-2"')
         parser.add_argument("-n", double_hyphen + octopus_name_key,
                             help="customized octopus server name, used for folder name")
         parser.add_argument("-k", double_hyphen + api_key_key,
                             help="api key for octopus; either api_key or user_name and password are required")
-        parser.add_argument("-u", double_hyphen + user_name_key,
+        parser.add_argument("-user", double_hyphen + user_name_key,
                             help="user_name for octopus; either api_key or user_name and password are required")
-        parser.add_argument("-p", double_hyphen + password_key,
+        parser.add_argument("-pass", double_hyphen + password_key,
                             help="password for octopus; either api_key or user_name and password are required")
         parser.add_argument("-sre", "--source_endpoint", help="source octopus endpoint for clone")
         parser.add_argument("-srn", "--source_octopus_name",
@@ -90,6 +92,7 @@ class OctopusClient:
                             help="password for octopus; either api_key or user_name and password are required")
         parser.add_argument("-srs", "--source_space_id_name",
                             help="source octopus space id or name for clone/migration")
+        parser.add_argument("-srm", "--source_pem", help="source octopus endpoint root pem file path")
         parser.add_argument("-lsr", "--local_source", help="if present, local_source = True; the source server/space "
                                                            "data are stored as YAML files locally", action='store_true')
         parser.add_argument("-a", "--action", help=str(Actions.__dict__.values()), required=True)
@@ -158,6 +161,8 @@ class OctopusClient:
             self._target_config.password = args.password
         assert self._target_config.api_key or (self._target_config.user_name and self._target_config.password), \
             f"either api_key or user_name and password are required"
+        if args.pem:
+            self._target_config.pem = args.pem
 
         if args.overwrite:
             self._target_config.overwrite = args.overwrite
@@ -177,12 +182,12 @@ class OctopusClient:
 
         if args.action in OctopusClient.CLONE_ACTIONS_SET:
             self._target_common.log_info_print(msg=f"===== Action: {args.action}; processing the source config =====")
+            self._source_config = copy.deepcopy(self._target_config)
+            self._source_common = Common(config=self._source_config)
 
             if args.local_source:
                 self._source_config.local_source = args.local_source
-            if not args.source_endpoint or args.source_endpoint == self._target_config.endpoint:
-                self._source_config.endpoint = self._target_config.endpoint
-            else:
+            if args.source_endpoint:
                 self._source_config.endpoint = args.source_endpoint
             assert self._source_config.local_source or self._source_config.endpoint.endswith("/api/"), \
                 f"octopus endpoint must end with /api/; {self._source_config.endpoint} is invalid"
@@ -192,9 +197,7 @@ class OctopusClient:
             if octopus_demo_site == self._source_config.endpoint:
                 self._source_config.item_type_runbook_processes = runbook_process_prefix
 
-            if not args.source_octopus_name or args.source_octopus_name == self._target_config.octopus_name:
-                self._source_config.octopus_name = self._target_config.octopus_name
-            else:
+            if args.source_octopus_name:
                 self._source_config.octopus_name = args.source_octopus_name
             assert self._source_config.octopus_name, "source octopus_name must not be empty"
             if self._target_config.endpoint != self._source_config.endpoint \
@@ -211,8 +214,11 @@ class OctopusClient:
                 self._source_config.password = args.source_password
             assert self._source_config.api_key or (self._source_config.user_name and self._source_config.password), \
                 f"either api_key or user_name and password are required"
+            if args.source_pem:
+                self._source_config.pem = args.source_pem
 
             if args.source_space_id_name:
+                self._source_config.space_id = None
                 self._source_config.space_id = self._source_common.verify_space(space_id_name=args.source_space_id_name)
                 if self._source_config.space_id:
                     self._target_common.log_info_print(msg=f"The source octopus space_id is: "
